<?php
/**
*
* Admin Notices
*
* @package Protect for WooCommerce
* @author  Protect, Inc.
* @license Proprietary
* @link    https://protect.inc
**/

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Woo_Protect_Admin_Notices {

    private $_protect;
    /**
    * Constructor
    **/
    function __construct() {
        $this->_protect = Woo_Protect_Base::getInstance();
        add_action('admin_notices', array( $this, 'shop_connection_notice' ) );
        add_action('admin_notices', array( $this, 'active_payment_method_notice' ) );
        add_action('admin_notices', array( $this, 'protect_portal_link' ) );
    }

    function user_shop_installed() {
        $apiUrl     = get_option( 'wc_protect_api_url' );
        $scgUrl     = get_option( 'wc_protect_scg_url' );
        $publicKey  = get_option( 'wc_protect_public_key' );
        $apiKey     = get_option( 'wc_protect_api_key' );

        return $apiUrl && $scgUrl && $publicKey;
    }
    /**
    * Notify if plugin was installed and needs user and shop created and connected in Protect.
    * @since 1.0.0
    **/
    function shop_connection_notice() {

        if ( !$this->_protect->isProtectConnected() || $this->_protect->requestOauthUpdate() || $this->_protect->areWebhooksMissing()) {
            $storeUrl   = get_bloginfo('url');
            $apiUrl     = get_option( 'wc_protect_api_url' ) ?: 'https://api.protect.inc';
            ?>
            <div class="notice notice-error">
                <div class="protect-notice-header">
                    <h3>
                        <?php echo __( "Action Required" ); ?>
                    </h3>
                </div>
                <div class="protect-notice-body">
                    <?php
                        printf(
                            __( "%s Click to link your shop. %sProtect for WooCommece%s will NOT work without connecting.", WC_PROTECT_CODE ),
                            '<a class="button-primary protect-notice-button" href="'.$apiUrl.'/woocommerce/install?store_url='.$storeUrl.'">' . $this->_protect->getLogoMonochromeSvg(20,16) .' ' . __( 'Connect Protect', WC_PROTECT_CODE ) . '</a>',
                            '<strong>',
                            '</strong>',
                        );
                    ?>
                </div>
                <p> </p>
            </div>
            <?php
        }
    }

    /**
    * Notify if no active payment method available.
    * @since 1.0.0
    **/
    function active_payment_method_notice() {

        $validPaymentMethod = get_option( 'wc_protect_valid_payment_method' );
        if ( $validPaymentMethod == 'no' && $this->_protect->isProtectConnected()) {
            ?>

            <div class="notice notice-error">
                <div class="protect-notice-header">
                    <h3>
                        <?php echo __( "Missing Payment Method" ); ?>
                    </h3>
                </div>
                <div class="protect-notice-body">
                    <?php
                        printf(
                            __( "To ensure %sProtect for WooCommerce%s remains functional, update your payment method in the %s.", WC_PROTECT_CODE ),
                            '<strong>',
                            '</strong>',
                            '<a href="https://portal.protect.inc"><strong>' . __( 'Protect Portal', WC_PROTECT_CODE ) . '</strong></a>'
                        );
                    ?>
                </div>
                <p> </p>
            </div>

            <?php
        }
    }

    function protect_portal_link() {

        if (
            isset( $_GET['page'] )
            && $_GET['page'] == 'wc-settings'
            && isset( $_GET['tab'] )
            && $_GET['tab'] == 'protect'
        ) {
            ?>
            <div class="notice notice-success">
            <div class="protect-notice-header">
                    <h3>
                        <?php echo __( "Protect Portal" ); ?>
                    </h3>
                </div>
                <div class="protect-notice-body">
                    <?php
                        printf(
                            __( "%s Check claims, revenue, analytics, or particpate in joint marketing, causes, partnerships, and everything else.", WC_PROTECT_CODE ),
                            '<a class="button-primary protect-notice-button" href="https://portal.protect.inc">' . $this->_protect->getLogoMonochromeSvg(20,16) .' ' . __( 'Launch the Protect Portal', WC_PROTECT_CODE ) . '</a>'
                        );
                    ?>
                </div>
                <p> </p>
            </div>
        <?php
        }
    }
}
