<?php
/**
* @package Protect for WooCommerce
* @author  Protect, Inc.
* @license Proprietary
* @link    https://protect.inc
**/

if ( ! defined( 'ABSPATH' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	exit;
}

if ( ! class_exists( 'Woo_Protect_Admin_Settings' ) ) :

function protect_admin_add_settings( $settings ) {

	/**
	 * Settings class
	 * @since 1.0.0
	 */
	class Woo_Protect_Admin_Settings extends \WC_Settings_Page {

        protected $id, $label, $_protect;

		/**
		 * Settings
		 * @since  1.0.0
		 */
		public function __construct() {

            $this->_protect = Woo_Protect_Base::getInstance();
			$this->id       = WC_PROTECT_CODE;
			$this->label    = __( 'Protect', WC_PROTECT_CODE );

			add_filter( 'woocommerce_settings_tabs_array',                  array( $this, 'add_settings_page' ), 20 );
			add_action( 'woocommerce_settings_' . $this->id,                array( $this, 'output' ) );
			add_action( 'woocommerce_settings_save_' . $this->id,           array( $this, 'save' ) );
			add_action( 'woocommerce_sections_' . $this->id,                array( $this, 'output_sections' ) );

            // After successfuly install, grab params and store it into the settings.
            if ( isset($_REQUEST['success']) && $_REQUEST['success']==1 ) {

                if ( isset($_REQUEST['apiUrl']) ) update_option( 'wc_protect_api_url',      $_REQUEST['apiUrl'] );
                if ( isset($_REQUEST['scgUrl']) ) update_option( 'wc_protect_scg_url',      $_REQUEST['scgUrl'] );
                if ( isset($_REQUEST['pubKey']) ) update_option( 'wc_protect_public_key',   $_REQUEST['pubKey'] );
                if ( isset($_REQUEST['apiKey']) ) update_option( 'wc_protect_api_key',      $_REQUEST['apiKey'] );

                update_option( 'wc_protect_request_oauth_update', 'no' );

                if ( isset( $_REQUEST['token'] ) ) {

                    $token          = $_REQUEST['token'];
                    $shopId         = $_REQUEST['shop_id'];
                    $userId         = $_REQUEST['user_id'];
                    $apiUrl         = get_option( 'wc_protect_api_url' );
                    $user           = wp_get_current_user();
                    $wpUserId       = get_current_user_id();

                    $blogName       = get_bloginfo('name');
                    $blogDesc       = get_bloginfo('description');
                    $blogEmail      = get_bloginfo('admin_email');
                    $blogLang       = get_bloginfo('language');
                    $blogUrl        = get_bloginfo('url');
                    $blogVersion    = get_bloginfo('version');


                    $bPhone         = get_user_meta($wpUserId,'billing_phone',true);
                    $sPhone         = get_user_meta($wpUserId,'shipping_phone',true);
                    $phone          = $bPhone ? $bPhone : $sPhone;

                    $address1       = get_user_meta($wpUserId,'billing_address_1',true);
                    $address2       = get_user_meta($wpUserId,'billing_address_2',true);
                    $company        = get_user_meta($wpUserId,'billing_company',true);
                    $city           = get_user_meta($wpUserId,'billing_city',true);
                    $state          = get_user_meta($wpUserId,'billing_state',true);
                    $postcode       = get_user_meta($wpUserId,'billing_postcode',true);
                    $country        = get_user_meta($wpUserId,'billing_country',true);


                    $ch = curl_init();
                    curl_setopt($ch, CURLOPT_URL,"$apiUrl/woocommerce/usershop/$token");
                    curl_setopt($ch, CURLOPT_POST, 1);
                    curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query([

                        'shop_id'           => $shopId,
                        'user_id'           => $userId,
                        'first_name'        => $user->user_firstname,
                        'last_name'         => $user->user_lastname,
                        'email'             => $user->user_email,
                        'phone'             => $phone,
                        'time_zone'         => wp_timezone_string(),
                        'currency_code'     => get_woocommerce_currency(),

                        'blog_name'         => $blogName,
                        'blog_description'  => $blogDesc,
                        'blog_email'        => $blogEmail,
                        'blog_language'     => $blogLang,
                        'blog_url'          => $blogUrl,
                        'blog_version'      => $blogVersion,

                        'address1'          => $address1,
                        'address2'          => $address2,
                        'company'           => $company,
                        'city'              => $city,
                        'state'             => $state,
                        'postcode'          => $postcode,
                        'country'           => $country,
                    ]));

                    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
                    $response = curl_exec($ch);
                    curl_close($ch);
                }
            }
		}

		/**
		 * Get settings sections
         * $all = true grabs hidden ones.
		 * @since 1.0.0
		 * @return array
		 */
		public function get_sections( $all = false ) {

			$sections = array(
				'settings'      => __( 'Settings', WC_PROTECT_CODE ),
                'integrations'  => __( 'Integrations', WC_PROTECT_CODE ),
			);

            if ( $all ) {
                $sections = array_merge( $sections, [
                    'protect'   => __( 'Protect', WC_PROTECT_CODE ),
                    'custom'    => __( 'Custom', WC_PROTECT_CODE ),
                ] );
            }

			return apply_filters( 'woocommerce_get_sections_' . $this->id, $sections );
		}

		/**
		 * Get Settings
		 * @since 1.0.0
		 * @param string $current_section Optional. Defaults to empty string.
		 * @return array Settings Array
		 */
		public function get_settings( $current_section = '' ) {
            $scgUrl     = get_option( 'wc_protect_scg_url' );
            $publicKey  = get_option( 'wc_protect_public_key' );
            $widgetHtml = '<div id="protect_claim"><script src="'.$scgUrl.'/v2/claim-protect.js?api-key='.$publicKey.'"></script><div id="protect-file-claim"></div></div>';

            switch( $current_section ) {

                case 'settings': default:

                    $settings = apply_filters( 'wc_protect_settings_' . $current_section, array(

                        /*
                        array(
                            'name'      => __( 'Protect Widget', WC_PROTECT_CODE ),
                            'type'      => 'title',
                            'desc'      => sprintf( __( 'Use %1$s[protect_widget]%2$s shortcode on any widget, post, or page. It will inherit these settings. %1$sDo NOT%2$s use the shortcode on the cart or checkout pages if you enable Protect using the checkboxes below.', WC_PROTECT_CODE ), '<strong>', '</strong>' ),
                            'id'        => 'wc_protect_section_widget_title'
                        ),

                        array(
                            'name'      => __( 'Protect Claim', WC_PROTECT_CODE ),
                            'type'      => 'title',
                            'desc'      => sprintf( __( 'Use %1$s[protect_claim]%2$s shortcode on any widget, post, or page. It will inherit these settings.', WC_PROTECT_CODE ), '<strong>', '</strong>' ),
                            'id'        => 'wc_protect_section_claim_title'
                        ),
                        */

                        array(
                            'name'      => __( 'Protect Claim (Manual)', WC_PROTECT_CODE ),
                            'type'      => 'title',
                            'desc'      => __( 'Create a new Page with a single HTML block with the following contents:', WC_PROTECT_CODE ) .'<br/>' . htmlspecialchars($widgetHtml),
                            'id'        => 'wc_protect_section_claim_manual_title'
                        ),


                        array(
                            'name'      => __( 'Protect Settings', WC_PROTECT_CODE ),
                            'type'      => 'title',
                            'desc'      => '',
                            'id'        => 'wc_protect_section_title'
                        ),

                        array(
                            'name'      => __( 'Enabled on Cart page', WC_PROTECT_CODE ),
                            'type'      => 'select',
                            'desc'      => __( 'If checked, Protect will appear on the Cart page.', WC_PROTECT_CODE ),
                            'options'   => array(
                                'no'    => __( 'No', WC_PROTECT_CODE ),
                                'yes'   => __( 'Yes', WC_PROTECT_CODE )
                            ),
                            'label'     => __( 'Enable', WC_PROTECT_CODE ),
                            'id'        => 'wc_protect_cart_enabled'
                        ),

                        array(
                            'name'      => __( 'Protect Widget location on the Cart page', WC_PROTECT_CODE ),
                            'type'      => 'select',
                            'desc'      => __( 'Select the Protect Widget location on the Cart page. Please make sure to enable Protect using the checkbox above.', WC_PROTECT_CODE ),
                            'options'   => array(
                                // All Locations
                                'woocommerce_before_cart'                       => __( 'Before cart.', WC_PROTECT_CODE ),
                                'woocommerce_before_cart_table'                 => __( 'Before cart table.', WC_PROTECT_CODE ),
                                'woocommerce_before_cart_contents'              => __( 'Before cart contents.', WC_PROTECT_CODE ),
                                'woocommerce_cart_contents'                     => __( 'Cart contents.', WC_PROTECT_CODE ),
                                'woocommerce_cart_coupon'                       => __( 'After cart coupon.', WC_PROTECT_CODE ),
                                'woocommerce_cart_actions'                      => __( 'Before cart actions.', WC_PROTECT_CODE ),
                                'woocommerce_after_cart_contents'               => __( 'After cart contents.', WC_PROTECT_CODE ),
                                'woocommerce_after_cart_table'                  => __( 'After cart table.', WC_PROTECT_CODE ),
                                'woocommerce_cart_collaterals'                  => __( 'Cart collaterals.', WC_PROTECT_CODE ),
                                'woocommerce_before_cart_totals'                => __( 'Before cart totals.', WC_PROTECT_CODE ),
                                'woocommerce_cart_totals_before_shipping'       => __( 'Cart totals before shipping.', WC_PROTECT_CODE ),
                                'woocommerce_after_shipping_rate'               => __( 'After shipping rate.', WC_PROTECT_CODE ),
                                'woocommerce_before_shipping_calculator'        => __( 'Before shipping calculator.', WC_PROTECT_CODE ),
                                'woocommerce_after_shipping_calculator'         => __( 'After shipping calculator.', WC_PROTECT_CODE ),
                                'woocommerce_cart_totals_after_shipping'        => __( 'Within cart totals after shipping.', WC_PROTECT_CODE ),
                                'woocommerce_cart_totals_before_order_total'    => __( 'Within cart totals before order total.', WC_PROTECT_CODE ),
                                'woocommerce_cart_totals_after_order_total'     => __( 'Within cart totals after order total.', WC_PROTECT_CODE ),
                                'woocommerce_proceed_to_checkout'               => __( 'Before checkout button.', WC_PROTECT_CODE ),
                                'woocommerce_after_cart_totals'                 => __( 'After the cart totals.', WC_PROTECT_CODE ),
                                'woocommerce_after_cart'                        => __( 'After the cart.', WC_PROTECT_CODE ),
                            ),
                            'id'        => 'wc_protect_cart_location',
                            'default'   => 'woocommerce_after_cart_table'
                        ),

                        array(
                            'name'      => __( 'Enabled on Mini Cart', WC_PROTECT_CODE ),
                            'type'      => 'select',
                            'desc'      => __( 'If checked, Protect will appear on the Mini Cart.', WC_PROTECT_CODE ),
                            'options'   => array(
                                'no'    => __( 'No', WC_PROTECT_CODE ),
                                'yes'   => __( 'Yes', WC_PROTECT_CODE )
                            ),
                            'label'     => __( 'Enable', WC_PROTECT_CODE ),
                            'id'        => 'wc_protect_mini_cart_enabled'
                        ),

                        array(
                            'name'      => __( 'Protect Widget location on the Mini Cart page', WC_PROTECT_CODE ),
                            'type'      => 'select',
                            'desc'      => __( 'Select the Protect Widget location on the Cart page. Please make sure to enable Protect using the checkbox above.', WC_PROTECT_CODE ),
                            'options'   => array(
                                // All Locations
                                'woocommerce_before_mini_cart'                      => __( 'Before Mini Cart.', WC_PROTECT_CODE ),
                                'woocommerce_before_mini_cart_contents'             => __( 'Before Mini Cart contents.', WC_PROTECT_CODE ),
                                'woocommerce_mini_cart_contents'                    => __( 'Mini Cart contents.', WC_PROTECT_CODE ),
                                'woocommerce_widget_shopping_cart_total'            => __( 'Shopping cart total.', WC_PROTECT_CODE ),
                                'woocommerce_widget_shopping_cart_before_buttons'   => __( 'Shopping cart before buttons.', WC_PROTECT_CODE ),
                                'woocommerce_widget_shopping_cart_after_buttons'    => __( 'Shopping cart after buttons.', WC_PROTECT_CODE ),
                            ),
                            'id'        => 'wc_protect_mini_cart_location',
                            'default'   => 'woocommerce_before_mini_cart_contents'
                        ),

                        array(
                            'name'      => __( 'Enabled on Checkout page', WC_PROTECT_CODE ),
                            'type'      => 'select',
                            'desc'      => __( 'If checked, Protect will appear under the Checkout form on the Checkout page', WC_PROTECT_CODE ),
                            'options'   => array(
                                'no'    => __( 'No', WC_PROTECT_CODE ),
                                'yes'   => __( 'Yes', WC_PROTECT_CODE )
                            ),
                            'label'     => __( 'Enable', WC_PROTECT_CODE ),
                            'id'        => 'wc_protect_checkout_enabled'
                        ),

                        array(
                            'name'      => __( 'Protect Widget location on the Checkout page', WC_PROTECT_CODE ),
                            'type'      => 'select',
                            'desc'      => __( 'Select the location of the Widget on the checkout page. Please make sure to enable Protect using the checkbox above.', WC_PROTECT_CODE ),
                            'options'   => array(
                                // Top
                                'woocommerce_before_checkout_form'                  => __( 'Before checkout form.', WC_PROTECT_CODE ),
                                'woocommerce_before_customer_details'               => __( 'Before customer details.', WC_PROTECT_CODE ),
                                // Left Side
                                'woocommerce_checkout_billing'                      => __( 'Checkout billing.', WC_PROTECT_CODE ),
                                'woocommerce_before_checkout_billing_form'          => __( 'Before checkout billing form.', WC_PROTECT_CODE ),
                                'woocommerce_after_checkout_billing_form'           => __( 'After checkout billing form.', WC_PROTECT_CODE ),
                                'woocommerce_before_checkout_registration_form'     => __( 'Before checkout registration form.', WC_PROTECT_CODE ),
                                'woocommerce_after_checkout_registration_form'      => __( 'After checkout registration form.', WC_PROTECT_CODE ),
                                'woocommerce_checkout_shipping'                     => __( 'Checkout shipping.', WC_PROTECT_CODE ),
                                'woocommerce_before_checkout_shipping_form'         => __( 'Before checkout shipping form.', WC_PROTECT_CODE ),
                                'woocommerce_after_checkout_shipping_form'          => __( 'After checkout shipping form.', WC_PROTECT_CODE ),
                                'woocommerce_before_order_notes'                    => __( 'Before order notes.', WC_PROTECT_CODE ),
                                'woocommerce_checkout_after_customer_details'       => __( 'Checkout after customer details.', WC_PROTECT_CODE ),
                                // Right Side
                                'woocommerce_checkout_before_order_review_heading'  => __( 'Before order review heading.', WC_PROTECT_CODE ),
                                'woocommerce_checkout_before_order_review'          => __( 'Before order review.', WC_PROTECT_CODE ),
                                'woocommerce_checkout_order_review'                 => __( 'Order review.', WC_PROTECT_CODE ),
                                'woocommerce_review_order_before_cart_contents'     => __( 'Review order before cart contents.', WC_PROTECT_CODE ),
                                'woocommerce_review_order_after_cart_contents'      => __( 'Review order after cart contents.', WC_PROTECT_CODE ),
                                'woocommerce_review_order_before_shipping'          => __( 'Review order before shipping.', WC_PROTECT_CODE ),
                                'woocommerce_review_order_after_shipping'           => __( 'Review order after shipping.', WC_PROTECT_CODE ),
                                'woocommerce_review_order_before_order_total'       => __( 'Review order before order total.', WC_PROTECT_CODE ),
                                'woocommerce_review_order_after_order_total'        => __( 'Review order after order total.', WC_PROTECT_CODE ),
                                'woocommerce_review_order_before_payment'           => __( 'Review order before payment.', WC_PROTECT_CODE ),
                                'woocommerce_review_order_before_submit'            => __( 'Review order before submit.', WC_PROTECT_CODE ),
                                'woocommerce_review_order_after_submit'             => __( 'Review order after submit.', WC_PROTECT_CODE ),
                                'woocommerce_review_order_after_payment'            => __( 'Review order after payment.', WC_PROTECT_CODE ),
                                // Bottom
                                'woocommerce_checkout_after_order_review'           => __( 'Checkout after order review.', WC_PROTECT_CODE ),
                                'woocommerce_after_checkout_form'                   => __( 'After checkout form.', WC_PROTECT_CODE ),
                            ),
                            'id'        => 'wc_protect_checkout_location'
                        ),

                        array(
                            'name'      => __( 'Is taxable', WC_PROTECT_CODE ),
                            'type'      => 'select',
                            'desc'      => __( 'If checked, the Protect amount will be taxed per your WooCommerce Tax settings.', WC_PROTECT_CODE ),
                            'options'   => array(
                                'yes'   => __( 'Yes', WC_PROTECT_CODE ),
                                'no'    => __( 'No', WC_PROTECT_CODE )
                            ),
                            'label'     => __( 'Enable', WC_PROTECT_CODE ),
                            'id'        => 'wc_protect_is_taxable'
                        ),

                        array(
                            'type'      => 'sectionend',
                            'id'        => 'protect_general_group'
                        ),

                    ) );

                break;
                case 'protect':
                    $settings = apply_filters( 'wc_protect_settings_' . $current_section, array(

						array(
                            'name'      => __( 'Custom', WC_PROTECT_CODE ),
                            'type'      => 'title',
                            'desc'      => '',
                            'id'        => 'protect_protect_title',
                        ),

                        array(
                            'name'      => __( 'Plugin Updater URL', WC_PROTECT_CODE ),
                            'type'      => 'text',
                            'id'        => 'wc_protect_updater_url',
                            'desc'      => __( 'Secure URL for plugin updater.', WC_PROTECT_CODE ),
                            'default'   => 'https://protect.inc/updater/wordpress/info.json'
                        ),

                        array(
                            'name'      => __( 'API Base URL', WC_PROTECT_CODE ),
                            'type'      => 'text',
                            'id'        => 'wc_protect_api_url',
                            'desc'      => __( 'Base URL for Protect API.', WC_PROTECT_CODE ),
                            'default'   => 'https://api.protect.inc'
                        ),

                        array(
                            'name'      => __( 'SCG Base URL', WC_PROTECT_CODE ),
                            'type'      => 'text',
                            'id'        => 'wc_protect_scg_url',
                            'desc'      => __( 'Base URL for Snippet Code Generator.', WC_PROTECT_CODE ),
                            'default'   => 'https://cdn.snippet.protect.inc'
                        ),

                        array(
                            'name'      => __( 'Public Key', WC_PROTECT_CODE ),
                            'type'      => 'text',
                            'id'        => 'wc_protect_public_key',
                            'desc'      => __( 'The Protect Public Key. Created during install. DO NOT CHANGE.', WC_PROTECT_CODE ),
                        ),

                        array(
                            'name'      => __( 'API Key', WC_PROTECT_CODE ),
                            'type'      => 'text',
                            'id'        => 'wc_protect_api_key',
                            'desc'      => __( 'The Protect API Key. Provided by Protect upon request and approval.', WC_PROTECT_CODE ),
                        ),

                        array(
                            'name'      => __( 'Valid Payment Method', WC_PROTECT_CODE ),
                            'type'      => 'checkbox',
                            'id'        => 'wc_protect_valid_payment_method',
                            'desc'      => __( 'Synced from Portal to indicate if the Merchant has a valid payment method on file.', WC_PROTECT_CODE ),
                        ),

                        array(
                            'name'      => __( 'Request Oauth Update', WC_PROTECT_CODE ),
                            'type'      => 'checkbox',
                            'id'        => 'wc_protect_request_oauth_update',
                            'desc'      => __( 'This will prompt the user to renew the Oauth permissions by showing them the admin notice.', WC_PROTECT_CODE ),
                        ),

						array(
                            'type'      => 'sectionend',
                            'id'        => 'protect_protect_group'
                        ),

                    ) );
                    break;
                case 'custom':

                    $settings = apply_filters( 'wc_protect_settings_' . $current_section, array(

                        array(
                            'name'      => __( 'Custom', WC_PROTECT_CODE ),
                            'type'      => 'title',
                            'desc'      => '',
                            'id'        => 'protect_custom_title',
                        ),

                        array(
                            'name'      => __( 'Override Subtotal', WC_PROTECT_CODE ),
                            'type'      => 'select',
                            'desc'      => __( 'If checked and the Subtotal Function is not empty, it will enable the override.', WC_PROTECT_CODE ),
                            'options'   => array(
                                'no'    => __( 'No', WC_PROTECT_CODE ),
                                'yes'   => __( 'Yes', WC_PROTECT_CODE )
                            ),
                            'label'     => __( 'Enable', WC_PROTECT_CODE ),
                            'id'        => 'wc_protect_custom_subtotal_enabled'
                        ),

                        array(
                            'name'      => __( 'Subtotal Function', WC_PROTECT_CODE ),
                            'type'      => 'textarea',
                            'id'        => 'wc_protect_custom_subtotal',
                            'desc'      => __( 'Override for obtaining the cart subtotal used for calculating Protect pricing.', WC_PROTECT_CODE ),
                        ),

                        array(
                            'type'      => 'sectionend',
                            'id'        => 'protect_custom_group'
                        ),

                    ) );
                break;
                case 'integrations':

                    $customSettingsHeader = array(
						array(
                            'name'      => __( 'Integrations', WC_PROTECT_CODE ),
                            'type'      => 'title',
                            'desc'      => 'Depending on what plugins you have installed, certain options will show up in this section.',
                            'id'        => 'protect_integrations_title',
                        )
                    );

                    $customSettingsBody = $this->_protect->getIntegrationsSettingsBody( [] );

                    $customSettingsFooter = array(
						array(
                            'type'      => 'sectionend',
                            'id'        => 'protect_integrations_group'
                        )
                    );

                    $customSettings = array_merge( $customSettingsHeader, $customSettingsBody, $customSettingsFooter );
                    $settings = apply_filters( 'wc_protect_settings_' . $current_section, $customSettings );
                break;

            }

			/**
			 * Filter Protect Settings
			 *
			 * @since 1.0.0
			 * @param array $settings Array of the plugin settings
			 */
			return apply_filters( 'woocommerce_get_settings_' . $this->id, $settings, $current_section );

		}


		/**
		 * Output the settings
		 *
		 * @since 1.0.0
		 */
		public function output() {

			global $current_section;

			$settings = $this->get_settings( $current_section );

			\WC_Admin_Settings::output_fields( $settings );

		}


		/**
	 	 * Save settings
	 	 *
	 	 * @since 1.0.0
		 */
		public function save() {

			global $current_section;

			$settings = $this->get_settings( $current_section );

			\WC_Admin_Settings::save_fields( $settings );

		}

	}

	$settings[] = new Woo_Protect_Admin_Settings();

	return $settings;

}
add_filter( 'woocommerce_get_settings_pages', 'protect_admin_add_settings', 15 );

endif;

?>
