protect_listen();

jQuery(document).ready(function() {
    protect_display_widget();
    protect_init();
});

function protect_listen() {
    window.addEventListener('protect::processWidget', () => {
        console.log('protect::processWidget');
        window.ProtectMethods.renderWidget();
    });

    window.addEventListener('protect::renderWidget::after', () => {
        console.log('protect::renderWidget::after');
        protect_refresh();
    });

    window.addEventListener('protect::reRenderWidget::after', () => {
        console.log('protect::reRenderWidget::after');
        // rerender
        protect_cart();
    });

    window.addEventListener('protect::widgetIsChecked', (e) => {
        console.log('protect::widgetIsChecked');
        protect_add();
    });

    window.addEventListener('protect::widgetIsUnChecked', (e) => {
        console.log('protect::widgetIsUnChecked');
        protect_remove();
    });
}

function protect_init() {

    protect_price();

    jQuery( document.body ).on( 'change', 'input[name^="shipping_method"]', function() {
        if ( protect_chosen_shipping( jQuery( this ), 'local_pickup' )) {
            jQuery( '.protect_widget').hide();
        } else {
            jQuery( '.protect_widget').show();
        }
    });
}

function protect_display_widget() {
    let protectIsHidden = false;
    jQuery( 'input[name^="shipping_method"]' ).each(function() {
        if ( protect_chosen_shipping( jQuery( this ), 'local_pickup' ) ) protectIsHidden = true;
    });
    if (protectIsHidden) jQuery( '.protect_widget').hide();
}

function protect_chosen_shipping( element, method ) {
    let chosenArray = element.val().split(':');
    if ( chosenArray.length == 2 ) { // [ label, id ]
        if ( chosenArray[0] == method && element.is(':checked') ) return true;
    }
    return false;
}

function protect_price() {

    jQuery.ajax({
        type: "POST",
        url: ProtectWC.apiUrl + '/price?protect=price',
        headers: {"x-protect-public-key": ProtectWC.apiKey, },
        dataType: 'json',
        data: ({"discount":ProtectWC.discount,"total_order_value":ProtectWC.subtotal,"line_items":[]}),
        success: function (result) {

            ProtectWC.price = result.price.toFixed(2);

            // Update Protect Widget Price
            window.dispatchEvent(new CustomEvent('protect::priceChanged', {
                detail: {
                    price: ProtectWC.price
                }
            }));

            console.log('Protect Price: ' + ProtectWC.price);
        }
    });
}

function protect_update_cart() {
    jQuery(document.body).trigger("wc_update_cart");
    jQuery(document.body).trigger( 'update_checkout' );
}
function protect_cart() {
    // Get Cart Info
    jQuery.ajax({
        type: "POST",
        url: ProtectWC.ajaxUrl,
        dataType: 'json',
        data: ({action: 'protect_cart', security: ProtectWC.nonce_cart}),
        success: function (protectCart) {
            if( protectCart ) {
                ProtectWC.cart      = protectCart.cart;
                ProtectWC.price     = protectCart.price;
                ProtectWC.discount  = protectCart.discount;
                ProtectWC.subtotal  = protectCart.subtotal;
                window.dispatchEvent(new CustomEvent('protect::priceChanged', {
                    detail: {
                        price: ProtectWC.price
                    }
                }));
                console.log(protectCart);
            }
        }
    });
}

function protect_refresh() {
    // Set Current State
    const detail = {
        protectVariant: {id:0,price:ProtectWC.price},
        checked: ProtectWC.checked,
        totalCart: ProtectWC.subtotal,
        cartHasVirtualProduct: false
    }
    const updateProtectStatusEvent = new CustomEvent('protect::updateProtectStatusEvent', {
        detail: detail
    })
    window.dispatchEvent(updateProtectStatusEvent);
    protect_display_widget();
}

function protect_add() {
    jQuery.ajax({
        type: "POST",
        url: ProtectWC.ajaxUrl,
        dataType: 'html',
        data: ({action: 'protect_add', price: ProtectWC.price, security: ProtectWC.nonce_add}),
        success: function (protectAdded) {
            if( protectAdded == 'success' ) {
                ProtectWC.checked = 1;
                protect_update_cart();
            }
        }
    });
}

function protect_remove() {
    jQuery.ajax({
        type: "POST",
        url: ProtectWC.ajaxUrl,
        dataType: 'html',
        data: ({action: 'protect_remove', security: ProtectWC.nonce_rem}),
        success: function (protectRemoved) {
            if( protectRemoved == 'success' ) {
                ProtectWC.checked = 0;
                protect_update_cart();
            }
        }
    });

}
