<?php
/**
*
* Main Frontend Controller
*
* @package Protect for WooCommerce
* @author  Protect, Inc.
* @license Proprietary
* @link    https://protect.inc
**/

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Woo_Protect_Main {

    private $_protect;

    /**
    * Frontend
    * @var object;
    **/
    private $views;

    /**
    * Settings
    * @var array;
    **/
    private $settings;

    /**
    * Constructor
    **/
    function __construct() {

        $this->_protect = Woo_Protect_Base::getInstance();
        $this->views    = new Woo_Protect_Main_Views;

        if( get_option('wc_protect_cart_enabled') == 'yes' && get_option('wc_protect_cart_location') ) {
            switch( get_option('wc_protect_cart_location') ) {
                default:
                    add_action( get_option('wc_protect_cart_location'), array( $this, 'protect_widget_cart' ) );
                break;
            }
        }
        if( get_option('wc_protect_mini_cart_enabled') == 'yes' && get_option('wc_protect_mini_cart_location') ) {
            switch( get_option('wc_protect_mini_cart_location') ) {
                default:
                    add_action( get_option('wc_protect_mini_cart_location'), array( $this, 'protect_widget_mini_cart' ) );
                break;
            }
        }


        if ( get_option('wc_protect_checkout_enabled') == 'yes' && get_option('wc_protect_checkout_location') ) {
            switch( get_option('wc_protect_checkout_location') ) {
                default:
                    add_action( get_option('wc_protect_checkout_location'), array( $this, 'protect_widget_checkout' ) );
                break;
            }
        }

        add_action( 'wp_ajax_protect_add', array( $this, 'protect_add' ) );
        add_action( 'wp_ajax_nopriv_protect_add', array( $this, 'protect_add' ) );

        add_action( 'wp_ajax_protect_remove', array( $this, 'protect_remove' ) );
        add_action( 'wp_ajax_nopriv_protect_remove', array( $this, 'protect_remove' ) );

        add_action( 'wp_ajax_protect_cart', array( $this, 'protect_cart' ) );
        add_action( 'wp_ajax_nopriv_protect_cart', array( $this, 'protect_cart' ) );

        //add_action( 'init', array( $this, '' ) );
        add_action( 'wp', array( $this->_protect, 'addProtectToCart' ) );

        add_action( 'woocommerce_cart_calculate_fees', array( $this->_protect, 'addProtectToCart' ), 100 );
        add_action( 'woocommerce_new_order', array( $this, 'protect_remove_on_order_placed' ) );

        // Shortcode
        add_shortcode( 'protect_widget_cart', array( $this, 'protect_widget_cart_shortcode' ) );
        add_shortcode( 'protect_widget_mini_cart', array( $this, 'protect_widget_mini_cart_shortcode' ) );
        add_shortcode( 'protect_widget_checkout', array( $this, 'protect_widget_checkout_shortcode' ) );
        add_shortcode( 'protect_claim', array( $this, 'protect_claim_shortcode' ) );

    }

    /**
     * Get cart data
     */
    function protect_cart() {
        check_ajax_referer( 'protect_cart', 'security' );

        $wcCart         = WC()->cart;
        $wcSession      = WC()->session;
        $subtotal       = $this->_protect->getSubtotal();
        $discount       = $this->_protect->getDiscount();
        $protect        = $wcSession ? $wcSession->get('protect') : array();
        $price          = @$protect['price'];
        $forced         = @$protect['forced'];

        $append = [
            'cart'          => $wcCart,
            'price'         => $price,
            'discount'      => $discount,
            'subtotal'      => $subtotal,
            'forced'        => $forced,
        ];

        echo json_encode($append);

        wp_die();
    }

    /**
    * Store Protect
    **/
    function protect_add() {

        check_ajax_referer( 'protect_add', 'security' );

        $protect = array(
            'price'     => floatval( sanitize_text_field( str_replace( ',', '.', $_POST['price'] ) ) ),
            'checked'   => true
        );

        $wcSession  = WC()->session;

        // Set Protect session object
        $wcSession->set( 'protect', $protect );
        // Persist user unchecked action.
        $wcSession->set( 'protectUnchecked', false );

        echo 'success';

        wp_die();
    }

    /**
    * Remove Protect
    **/
    function protect_remove() {

        check_ajax_referer( 'protect_remove', 'security' );

        $wcSession = WC()->session;

        // Unset Protect session object
        $wcSession->__unset( 'protect' );
        // Persist user unchecked action.
        $wcSession->set( 'protectUnchecked', true );

        echo 'success';

        wp_die();
    }


    /**
    * Remove Protect when an order is placed.
    **/
    function protect_remove_on_order_placed( $orderid ) {
        if( !is_admin() ) {
            $wcSession = WC()->session;
            if( $wcSession && $wcSession->get( 'protect' ) ) {
                $wcSession->__unset( 'protect' );
                $wcSession->__unset( 'protectUnchecked' );
            }
        }
    }

    /**
    * Protect Widget Cart Shortcode callback
    **/
    function protect_widget_cart_shortcode() {
        $this->protect_widget_cart();
    }
    function protect_widget_mini_cart_shortcode() {
        $this->protect_widget_mini_cart();
    }
    function protect_widget_checkout_shortcode() {
        $this->protect_widget_checkout();
    }

    /**
    * Protect Cart Widget
    **/
    function protect_widget_cart() {

        $show = apply_filters( 'wc_protect_display_cart_widget', 1 );

        if( $show ) {
            wp_enqueue_style( 'protect-css' );
            wp_enqueue_script( 'protect-js' );
            echo $this->views->protect_widget_cart();
        }
    }

    /**
    * Protect Mini Cart Widget
    **/
    function protect_widget_mini_cart() {

        $show = apply_filters( 'wc_protect_display_mini_cart_widget', 1 );

        if( $show ) {
            wp_enqueue_style( 'protect-css' );
            wp_enqueue_script( 'protect-js' );
            echo $this->views->protect_widget_mini_cart();
        }
    }


    /**
    * Protect Checkout Widget
    **/
    function protect_widget_checkout() {

        $show = apply_filters( 'wc_protect_display_checkout_widget', 1 );

        if( $show ) {
            wp_enqueue_style( 'protect-css' );
            wp_enqueue_script( 'protect-js' );
            echo $this->views->protect_widget_checkout();
        }
    }


    /**
    * Protect Claim Shortcode callback
    **/
    function protect_claim_shortcode() {
        $this->protect_claim();
    }

    /**
     * Protect Claim Widget
     */
    function protect_claim() {

        $show = apply_filters( 'wc_protect_display_claim', 1 );

        if( $show ) {
            wp_enqueue_style( 'protect-css' );
            wp_enqueue_script( 'protect-js' );
            echo $this->views->protect_claim();
        }
    }

}
?>
