<?php
/**
* @package Protect for WooCommerce
* @author  Protect, Inc.
* @license Proprietary
* @link    https://protect.inc
**/

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Woo_Protect_Api_V1 {

    protected $version = 1;
    private $_protect;

    /**
    * Constructor
    **/
    function __construct() {

        $this->_protect = Woo_Protect_Base::getInstance();

        add_action( 'rest_api_init', function () {
            register_rest_route( 'protect/v'.$this->version, '/settings', array(
                'methods'   => WP_REST_Server::READABLE,
                'callback'  => array( $this, 'get_settings' ),
                'permission_callback' => '__return_true',
                /*
                'permission_callback' => function ( $request ) {
                    return current_user_can('manage_options');

                }
                */
            ));
        });

        add_action( 'rest_api_init', function () {
            register_rest_route( 'protect/v'.$this->version, '/options(?:/(?P<id>\w+))?', array(
                'methods'   => WP_REST_Server::READABLE,
                'callback'  => array( $this, 'get_options' ),
                'args'      => array(
                    'id' => array(
                        'validate_callback' => function($param, $request, $key) {
                            return is_string( $param );
                        }
                    ),
                ),
                'permission_callback' => '__return_true',
                /*
                'permission_callback' => function ( $request ) {
                    return current_user_can('manage_options');
                }
                */
            ));
        });

        add_action( 'rest_api_init', function () {
            register_rest_route( 'protect/v'.$this->version, '/option', array( ///(?P<id>\w+)/(?P<value>\w+)
                'methods'   => WP_REST_Server::CREATABLE,
                'callback'  => array( $this, 'set_option' ),
                'args'      => array(
                    'id' => array(
                        'validate_callback' => function($param, $request, $key) {
                            return is_string( $param );
                        }
                    ),
                    'value' => array(

                    ),
                ),
                'permission_callback' => '__return_true',
                /*
                'permission_callback' => function ( $request ) {
                    return current_user_can('manage_options');
                }
                */
            ));
        });
    }

    /**
     * Get all settngs
     *
     * @param array $request Options for the function.
     * @return string|null Post title for the latest, * or null if none.
     */
    function get_settings( WP_REST_Request $request ) {

        require_once( __DIR__ . '/../admin/controllers/settings.class.php' );

        $id         = $request->get_param( 'id' );
        $settings   = protect_admin_add_settings( [] );
        $class      = new Woo_Protect_Admin_Settings;

        $results    = [];
        $sections   = $class->get_sections( true );

        foreach( $sections as $section => $label ) {
            $options = $class->get_settings( $section );
            $results[$section] = [ 'label' => $label, 'fields' => $options ];
        }


        if ( $id && empty($results) ) {
          return new WP_Error( 'no_setting', 'Invalid option id', array( 'status' => 404 ) );
        }

        $response = new WP_REST_Response( $results );
        $response->set_status( 201 );

        return $response;
    }

    /**
     * Get all option names and values
     *
     * @param array $request Options for the function.
     * @return string|null Post title for the latest, * or null if none.
     */
    function get_options( WP_REST_Request $request ) {

        require_once( __DIR__ . '/../admin/controllers/settings.class.php' );

        $id         = $request->get_param( 'id' );
        $settings   = protect_admin_add_settings( [] );
        $class      = new Woo_Protect_Admin_Settings;

        $results    = [];
        $sections   = $class->get_sections( true );

        foreach( $sections as $section => $label ) {

            $options = $class->get_settings( $section );
            foreach( $options as $option ) {
                switch ($option['type']) {
                    case 'title':
                    case 'sectionend':

                        break;
                    default:
                        if ( $id && isset($option['id']) ) {
                            if ( $id == $option['id'] ) {
                                $results[ $option['id'] ] = get_option( $option['id'] );
                            }
                        } else {
                            if ( isset($option['id']) ) $results[ $option['id'] ] = get_option( $option['id'] );
                        }

                        break;
                }
            }
        }


        if ( $id && empty($results) ) {
          return new WP_Error( 'no_setting', 'Invalid option id', array( 'status' => 404 ) );
        }

        // trying to figure out permissions
        //$user = wp_get_current_user();
        //$response = new WP_REST_Response( $user );

        $response = new WP_REST_Response( $results );
        $response->set_status( 201 );

        return $response;
    }

    function set_option( WP_REST_Request $request ) {
        $name       = $request->get_param('id');
        $value      = $request->get_param('value');
        $result     = update_option($name, $value);
        $response   = new WP_REST_Response( $result );
        return $response;
    }

}