<?php
/**
* @package Protect for WooCommerce
* @author  Protect, Inc.
* @license Proprietary
* @link    https://protect.inc
**/

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Woo_Protect_Base {

    /**
     * The unique instance of the class.
     *
     * @var Woo_Protect_Base
     */
    private static $_instance;

     /**
    * Constructor
    **/
    public function __construct() {

    }

    /**
     * Gets an instance of this class.
     *
     * @return Woo_Protect_Base
     */
    public static function getInstance() {
        if (null === self::$_instance) {
            self::$_instance = new self();
        }
        return self::$_instance;
    }

    /*
    public function log($msg) {
        if (WP_ENVIRONMENT_TYPE!='production') {
            $file = fopen(WP_CONTENT_DIR . "/debug.log", "a") or die("Unable to open file!");
            switch(gettype($msg)) {
                case 'object':
                case 'array':
                    fwrite($file, print_r($msg,true));
                    break;
                case 'string':
                default:
                    fwrite($file, $msg . PHP_EOL);
                    break;
            }
            fwrite($file,PHP_EOL);
            fclose($file);
        }
    }
    */


    /**
    * Add Protect fee to Cart
    **/
    function addProtectToCart() {

        if( !is_admin() && $this->isProtectConnected() && !$this->isLocalPickup() ) {

            $wcCart         = WC()->cart;
            $wcSession      = WC()->session;
            $publicKey      = get_option( 'wc_protect_public_key' );
            $userUnchecked  = @$wcSession->get('protectUnchecked');
            $subtotal       = $this->getSubtotal();
            $discount       = $this->getDiscount();

            $protect        = $wcSession ? $wcSession->get('protect') : array();
            $alwaysChecked  = @$protect['forced'];

            if( (!$userUnchecked || $alwaysChecked) && WC()->cart ) {

                $pricing    = $this->getProtectPricing($subtotal,$discount);

                if ( $pricing ) {

                    $price              = $pricing->price;
                    $autocheck          = isset( $pricing->checked_by_default ) ? $pricing->checked_by_default : true;
                    $forcecheck         = isset( $pricing->checkbox_always_checked ) ? $pricing->checkbox_always_checked : false;
                    $enabled            = isset( $pricing->enabled ) ? $pricing->enabled : true;


                    $protect['price']   = $price;
                    $protect['forced']  = $forcecheck;

                    // Set the Fees
                    $label              = WC_PROTECT_FEE_LABEL;
                    $price              = isset($protect['price']) ? @$protect['price'] : 0.99;
                    $isTaxable          = get_option('wc_protect_is_taxable') == 'yes' ? true : false;

                    if ( $enabled ) {
                        WC()->cart->add_fee( $label, $price, $isTaxable, '' );
                    }

                    // Update Session with latest Protect values
                    $wcSession->set( 'protect', $protect );
                }

            }
        }
    }

    /**
     * Check if a plugin is active.
     * $name:String. 'woocommerce/woocommerce.php'
     */
    public function isPluginActive( $name ) {
        foreach ( $this->getActivePlugins() as $plugin ) {
            if ( $name == $plugin ) return true;
        }
        return false;
    }
    public function getActivePlugins() {
        $plugins = apply_filters('active_plugins', get_option('active_plugins') );
        //echo '<pre>'; print_r( $plugins ); echo '</pre>'; // Use this to see the integration file and path (or just look in the plugins folder).
        return $plugins ?: [];
    }

    public function getLogoMonochromeSvg( $width = 50, $height = 50, $fill = '#FFFFFF' ) {
        return '<svg version="1.1" id="protect_logo_white_svg" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="50 50 400 330" style="width:'.$width.'px;height:'.$height.'px;" xml:space="preserve">' .
            '<style type="text/css"> .st0{ fill:'.$fill.'; }</style>' .
            '<g><g><path class="st0" d="M240.8,187.4c0-9.7-3.9-19.1-11-25.9l0,0c-31.8-31.3-83.5-31.3-115.4,0s-31.9,82,0,113.4l126.4,123.9V187.4L240.8,187.4z"/>' .
            '<path class="st0" d="M279.3,154.2c-10.8,8-19.5,20.8-19.5,44.7v199.9l44.7-43.7V203.5c0-8.8,5.7-17.1,14.2-19.4c2.1-0.6,4.3-1,6.5-1.2c1.2-0.1,2.3-0.1,3.4-0.1c10.1,0,19.5,3.8,26.5,10.7c6.7,6.6,10.6,15.4,10.6,24.8c0,9.3-2.9,17.1-10.6,24.8c-6.1,6.1-17.1,12-31.3,16.6V312c38.3-14.9,49.8-24.4,62.5-37.2c30.6-31,31.9-82,0-113.4C357,132.9,311.1,130.3,279.3,154.2z"/>' .
            '</g></g></svg>';
    }

    public function isProtectConnected() {
        $apiUrl     = get_option( 'wc_protect_api_url' );
        $scgUrl     = get_option( 'wc_protect_scg_url' );
        $publicKey  = get_option( 'wc_protect_public_key' );
        $apiKey     = get_option( 'wc_protect_api_key' );

        return $apiUrl && $scgUrl && $publicKey;
    }

    public function requestOauthUpdate() {
        return get_option( 'wc_protect_request_oauth_update' ) == 'yes';
    }

    public function getBaseDomain( $url ) {
        $host   = parse_url( $url, PHP_URL_HOST );
        $parts  = explode( '.', $host );
        array_shift( $parts );
        $base   = implode( '.', $parts );
        return $base;
    }

    public function areWebhooksMissing() {

        $statuses   = wc_get_webhook_statuses(); // active, paused, disabled
        $dataStore  = WC_Data_Store::load( 'webhook' );
        $webhooks   = $dataStore->get_webhooks_ids( ); // $status
        $bridgeBase = $this->getBaseDomain( 'https://bridge.io.synchroto.com' );
        $apiBase    = $this->getBaseDomain( get_option( 'wc_protect_api_url' ) );

        $topics     = array(
            'order.deleted'     => 1,
            'order.restored'    => 1,
            'order.updated'     => 1,
            'order.created'     => 1
        );

        foreach ( $webhooks as $id ) {

            $hook   = new WC_Webhook( $id );
            $topic  = trim( $hook->get_topic() );
            $base   = $this->getBaseDomain( $hook->get_delivery_url() );

            if ( $apiBase == $base || $bridgeBase == $base ) {

                if ( $hook->get_status() != 'active' ) {

                    $hook->set_status( 'active' );
                    $hook->save();
                }

                unset( $topics[ $topic ] );
            }
        }

        return count( $topics ) != 0;
    }

    /**
     * Checks if the $method is selected.
     * The cart session value `chosen_shipping_methods` can accomodate an array of choices.
     * This function only returns true if ONLY one option is selected matching the method.
     */
    public function isChosenShippingMethod( $method ) {

        $chosenMethods = WC()->session->get( 'chosen_shipping_methods' );

        if ( $chosenMethods && count($chosenMethods) == 1 ) {

            $chosenShippingArray    = explode( ':', $chosenMethods[0] );
            $chosenShipping         = count($chosenShippingArray) == 2 ? $chosenShippingArray[0] : $chosenMethods[0];

            if ($chosenShipping == $method) {
                return true;
            }
        }

        return false;
    }

    public function isLocalPickup() {
        return $this->isChosenShippingMethod( 'local_pickup' );
    }


    public function getIntegrationsSettingsBody( $settings ) {
        return apply_filters('protect_integrations_settings_body', $settings );
    }

    public function getProtectPricing($subtotal,$discount=0,$lineItems=[]) {

        if ( !$this->isProtectConnected() ) return null;

        $previewMode    = isset( $_GET['protect'] ) ? $_GET['protect'] == 'preview' : false;
        $apiUrl         = get_option( 'wc_protect_api_url' );
        $publicKey      = get_option( 'wc_protect_public_key' );

        $fields = array(
            'discount'          => $discount,
            'total_order_value' => $subtotal,
            'line_items'        => $lineItems
        );

        // Create a unique result key for the parameters so we can retrieve it on repeat requests.
        $resultKey  = md5(serialize($fields));
        $wcSession  = WC()->session;

        // Check if value was already calculated and return it.
        if( ! $previewMode && $wcSession && $wcSession->get( 'getProtectPricing_' . $resultKey ) ) {
            $json = $wcSession->get( 'getProtectPricing_' . $resultKey );
            $wcSession->set( 'getProtectPricing', $json ); // This always stores the latest value.
            return $json;
        }

        // Otherwise, get pricing from the server.
        $fieldsStr  = http_build_query($fields);
        $url        = $apiUrl . '/price?protect=price';
        $curl       = curl_init();
        curl_setopt($curl, CURLOPT_URL, $url);
        curl_setopt($curl, CURLOPT_POST, TRUE);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($curl, CURLOPT_POSTFIELDS, $fieldsStr);
        curl_setopt($curl, CURLOPT_HTTPHEADER, array('x-protect-public-key:'.$publicKey));
        $results    = curl_exec($curl);
        $json       = json_decode($results);

        //$enabled    = @$json->enabled;
        //$price      = @$json->price;
        //$autocheck  = @$json->checked_by_default;
        //$forcecheck = @$json->checkbox_always_checked;

        curl_close($curl);

        // Store into session for speed. Don't save if no result so it will try again.
        if ( $json ) {
            $wcSession->set( 'getProtectPricing_' . $resultKey, $json );
            $wcSession->set( 'getProtectPricing', $json ); // This always stores the latest value.
        }
        return $wcSession->get( 'getProtectPricing_' . $resultKey );
    }


    public function getIntegrationsDiscount( $discount ) {
        return apply_filters('protect_integrations_discount', $discount );
    }
    public function getDiscount() {
        $wcCart     = WC()->cart;
        $discount   = $wcCart->get_discount_total();

        return $this->getIntegrationsDiscount( $discount );
    }

    public function getIntegrationsSubtotal( $subtotal ) {
        return apply_filters('protect_integrations_subtotal', $subtotal );
    }

    public function getSubtotal() {

        $wcCart     = WC()->cart;
        $subtotal   = $wcCart->get_subtotal();
        return $this->getIntegrationsSubtotal( $subtotal );
    }

    public function isAllEnabled() {
        $mc     = get_option( 'wc_protect_mini_cart_enabled' );
        $c      = get_option( 'wc_protect_cart_enabled' );
        $co     = get_option( 'wc_protect_checkout_enabled' );

        return ($mc || $c || $co);
    }

}