<?php
/**
*
* Woo Custom Product Addons Integration
*
* @package Protect for WooCommerce
* @author  Protect, Inc.
* @license Proprietary
* @link    https://protect.inc
**/

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Protect_Woo_Custom_Product_Addons_Start {

    public function __construct() {
        add_filter( 'protect_integrations_settings_body', array( $this, 'protect_integrations_settings_body' ), 10, 1 );
        add_filter( 'protect_integrations_subtotal', array( $this, 'protect_integrations_subtotal' ), 10, 1 );
    }

    public function protect_integrations_settings_body( $settings ) {
        $settings = array_merge( $settings, [
            array(
                'text'      => __( 'Woo Custom Product Addons', WC_PROTECT_CODE ),
                'type'      => 'info',
            ),
            array(
                'name'      => __( 'Enable', WC_PROTECT_CODE ),
                'type'      => 'select',
                'desc'      => __( 'Use a value from the addon fields to calculate the Protect fee.', WC_PROTECT_CODE ),
                'options'   => array(
                    'no'    => __( 'No', WC_PROTECT_CODE ),
                    'yes'   => __( 'Yes', WC_PROTECT_CODE )
                ),
                'id'        => 'wc_protect_integrations__woo_custom_product_addons_enabled'
            ),
            array(
                'name'      => __( 'Label for Value', WC_PROTECT_CODE ),
                'type'      => 'text',
                'id'        => 'wc_protect_integrations__woo_custom_product_addons_label',
                'desc'      => __( 'Case-sensitive label of the field to use to calculate the Protect fee.', WC_PROTECT_CODE ),
            ),
        ]);

        return $settings;
    }

    public function protect_integrations_subtotal( $subtotal ) {

        if ( get_option( 'wc_protect_integrations__woo_custom_product_addons_enabled' ) == 'yes' && !is_admin() ) {

            $matchLabel = get_option( 'wc_protect_integrations__woo_custom_product_addons_label' );
            $wcCart     = WC()->cart;

            $amount = 0;
            foreach( $wcCart->cart_contents as $kItem => $item ) {

                if ( isset($item['wcpa_data']) && !empty($item['wcpa_data']) ) {

                    $quantity   = (float)$item['quantity'];

                    foreach( $item['wcpa_data'] as $kData => $data ) {
                        foreach ( $data['fields'] as $kField => $field ) {
                            $entry  = $field[0];
                            $label  = trim($entry['label']);
                            $name   = trim($entry['name']);
                            $value  = trim($entry['value']);

                            if ($label==$matchLabel) {
                                $amount += (float)$value * $quantity;
                            }
                        }
                    }
                }
            }
            $subtotal += $amount;
        }

        return $subtotal;
    }
}