<?php
/**
*
* WooCommerce Checkout Add-Ons Integration
*
* @package Protect for WooCommerce
* @author  Protect, Inc.
* @license Proprietary
* @link    https://protect.inc
**/

//use SkyVerge\WooCommerce\Checkout_Add_Ons\Add_Ons\Add_On_Factory;
use SkyVerge\WooCommerce\Checkout_Add_Ons\Add_Ons\Data_Store_Options;

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Protect_Woocommerce_Checkout_Add_Ons_Woocommerce_Checkout_Add_Ons {

    public function __construct() {
        // Core Overrides
        add_filter( 'protect_integrations_settings_body',           array( $this, 'protect_integrations_settings_body' ), 10, 1 );
        add_filter( 'protect_integrations_subtotal',                array( $this, 'protect_integrations_subtotal' ), 100, 1 );

        // Additional Functionality
        add_action( 'woocommerce_cart_calculate_fees',              array( $this, 'woocommerce_cart_calculate_fees' ), 20, 0 );
        add_filter( 'woocommerce_update_order_review_fragments',    array( $this, 'protect_refresh_checkout_widget' ), 100, 1 );

        add_action( 'init',                                         array( $this, 'check_flush_session_data' ) );
    }

    public function check_flush_session_data() {
        if ( isset( $_GET['flush'] ) ) {
            if ( WC()->session ) {
                WC()->session->checkout_add_ons = null;
            }
        }
    }

    public function getCurrentUrl() {
        return (empty($_SERVER['HTTPS']) ? 'http' : 'https') . "://$_SERVER[HTTP_HOST]$_SERVER[REQUEST_URI]";
    }

    public function protect_integrations_settings_body( $settings ) {

        $settings = array_merge( $settings, [
            array(
                'text'      => sprintf( __( 'WooCommerce Checkout Add-Ons (%1$sFlush Session%2$s)', WC_PROTECT_CODE ), '<a href="'.$this->getCurrentUrl().'&flush=1">', '</a>' ),
                'type'      => 'info',
            ),
            array(
                'name'      => __( 'Enable', WC_PROTECT_CODE ),
                'type'      => 'select',
                'desc'      => __( 'Use a value from the checkout addon field to calculate the Protect fee.', WC_PROTECT_CODE ),
                'options'   => array(
                    'no'    => __( 'No', WC_PROTECT_CODE ),
                    'yes'   => __( 'Yes', WC_PROTECT_CODE )
                ),
                'id'        => 'wc_protect_integrations__woocommerce_checkout_add_ons_enabled'
            ),
            array(
                'name'      => __( 'Label for Value', WC_PROTECT_CODE ),
                'type'      => 'text',
                'id'        => 'wc_protect_integrations__woocommerce_checkout_add_ons_label',
                'desc'      => __( 'Case-sensitive label of the field to use to calculate the Protect fee.', WC_PROTECT_CODE ),
            ),
        ]);

        return $settings;
    }


    public function protect_integrations_subtotal( $subtotal ) {

        if ( get_option( 'wc_protect_integrations__woocommerce_checkout_add_ons_enabled' ) == 'yes' && !is_admin() ) {

            $addons     = WC()->session->checkout_add_ons;

            if ( ! isset($addons['fees']) ) return $subtotal;

            $matchLabel = get_option( 'wc_protect_integrations__woocommerce_checkout_add_ons_label' );
            $dso        = new Data_Store_Options();

            $selected   = null;
            $amount     = 0;
            foreach ( $addons['fees'] as $key => $addon ) {

                $id     = $addon['id'];
                $vLabel = $addon['value'];
                $object = $dso->get_add_on_data( $id );

                if ( $object['label'] == $matchLabel ) {

                    if ( ! $object['enabled'] ) continue;

                    foreach ( $object['options'] as $option ) {

                        /*
                        Array
                        (
                            [label] => $9001-$10000
                            [adjustment] => 120
                            [adjustment_type] => fixed
                            [default] =>
                        )
                        */
                        $oLabel = $this->sanitizeLabel( $option['label'] );

                        if ( $vLabel == $oLabel ) {
                            $selected = $option;
                            break 2;
                        }
                    }
                }
            }

            if ( $selected ) {
                // Get the upper range amount. Ex: $1001-$2000 would be 2000.
                $range  = explode( '-', $this->sanitizeLabel( $selected['label'] ) );
                $amount = isset( $range[1] ) && is_numeric( $range[1] ) ? $range[1] : 0;

                if ( $amount >= $subtotal ) {
                    $subtotal = $amount;
                } else {
                    $subtotal += $amount;
                }
            }
        }

        //WC()->session->set( 'getProtectSubtotal_' . get_class( $this), $subtotal );
        return $subtotal;
    }

    /**
     * Supporting functions
     */

    public function sanitizeLabel( $label ) {
        return sanitize_title( esc_html( $label ) );
    }

    function protect_refresh_checkout_widget( $fragments ) {

        $json       = WC()->session->get( 'getProtectPricing' );
        $price      = (float)$json->price;

		$fragments['#protect__checkout'] = '<div id="protect__checkout">

        <script>
        ProtectWC.price     = '.$price.';
        window.dispatchEvent(new CustomEvent("protect::priceChanged", {
            detail: {
                price: ProtectWC.price
            }
        }));
        </script>

        </div>';

		return $fragments;
    }

    public function woocommerce_cart_calculate_fees() {
        // Remove new fees that start with the matching label.
        $matchLabel = get_option( 'wc_protect_integrations__woocommerce_checkout_add_ons_label' );
        // Remove the matching cart fee.
        $this->removeCartFee( $matchLabel );
    }

    function removeCartFee( $name ) {
        $found  = 0;
        $fees   = WC()->cart->get_fees();
        foreach ($fees as $key => $fee) {
            if ($fees[$key]->name === $name ) {
                unset($fees[$key]);
                $found = $fee;
                break;
            }
        }
        if ($found) WC()->cart->fees_api()->set_fees($fees);
        return $found;
    }
}