<?php
 /* =======================================================================
 *
 * PROTECT CONFIDENTIAL
 * ________________________________________________________________________
 *
 *  Copyright (C) Protect Inc. https://protect.inc
 *  All Rights Reserved.
 *
 * NOTICE: All information contained herein and its related files,
 * (the "Software") is, and remains the property of Protect
 * and its suppliers, if any. The intellectual and technical concepts
 * contained herein are proprietary to Protect and its suppliers and
 * may be covered by U.S. and Foreign Patents, patents in process, and
 * are protected by trade secret or copyright law. Dissemination of this
 * information or reproduction of this material or Software is strictly
 * forbidden unless prior written permission is obtained from Protect Inc.
 *
 * By using or accessing our Software or services and/or downloading our
 * files, related files, or assets you agree to all applicable terms that
 * can be found on our apps, websites, and other properties including any
 * other special terms for programs or agreements you have with us.
 =========================================================================*/

/*
* Plugin Name: Protect for WooCommerce
* Plugin URI: https://woocommerce.protect.inc
* Description: eCommerce Protection with a Cause.
* Version: 1.0.11
* Author: Protect, Inc.
* Author URI: https://protect.inc
* Text Domain: protect
* Domain Path: /languages
* WC requires at least: 3.0.0
* WC tested up to: 8.5.2
* License: Proprietary
*/

/**
* @package Protect for WooCommerce
* @author  Protect, Inc.
* @license Proprietary
* @link    https://protect.inc
**/


if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

define( 'WC_PROTECT_VER',       '1.0.11' );
define( 'WC_PROTECT_CODE',      'protect' );

define( 'WC_PROTECT_URL',       plugin_dir_url(     __FILE__ ) );
define( 'WC_PROTECT_PATH',      plugin_dir_path(    __FILE__ ) );
define( 'WC_PROTECT_BASE',      plugin_basename(    __FILE__ ) );

define( 'WC_PROTECT_FEE_LABEL', 'Protect' );

load_plugin_textdomain( WC_PROTECT_CODE, false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );

if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
    require_once( __DIR__ . '/frontend/init.php' );
    require_once( __DIR__ . '/integrations/init.php' );
    $integrations = new Woo_Protect_Integrations();
    if ( is_admin() ) {
        require_once( __DIR__ . '/admin/init.php' );
    }
}

require_once( __DIR__ . '/global/uninstall.php' );
function protect_deactivate_uninstall() {
    protect_uninstall();
    flush_rewrite_rules();
}
register_uninstall_hook( __FILE__, 'protect_deactivate_uninstall' );

/**
 * HPOS Compatibility
 */
add_action('before_woocommerce_init', function() {
    if ( class_exists( \Automattic\WooCommerce\Utilities\FeaturesUtil::class ) ) {
        \Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
    }
});


/**
 * Plugin Updater
*/
// Extra text in the update message box.
add_action( 'in_plugin_update_message-protect/protect.php', 'protect_updater_message', 10, 2 );
function protect_updater_message( $plugin_info_array, $plugin_info_object ) {
	if( empty( $plugin_info_array[ 'package' ] ) ) {
        //echo ' ' . __( 'Please renew your license to update. You can change your license key in WooCommerce > Settings > Protect', 'protect' );
	}
}
if ( ! class_exists( 'Woo_Protect_Updater' ) ) {

    class Woo_Protect_Updater {

        public $plugin_slug;
        public $version;
        public $cache_key;
        public $cache_allowed;

        public function __construct() {

            $this->plugin_slug      = plugin_basename( __DIR__ );
            $this->version          = WC_PROTECT_VER;
            $this->cache_key        = WC_PROTECT_CODE . '_' . WC_PROTECT_VER;
            $this->cache_allowed    = false;

            add_filter( 'plugins_api', array( $this, 'info' ), 20, 3 );
            add_filter( 'site_transient_update_plugins', array( $this, 'update' ) );
            add_action( 'upgrader_process_complete', array( $this, 'purge' ), 10, 2 );
        }

        public function request() {

            $remote     = get_transient( $this->cache_key );
            $updateUrl  = get_option( 'wc_protect_updater_url' ) ? get_option( 'wc_protect_updater_url' ) : 'https://protect.inc/updater/wordpress/info.json';

            if( false === $remote || ! $this->cache_allowed ) {

                $remote = wp_remote_get(
                    add_query_arg(
                        array(
                            'plugin'        => WC_PROTECT_CODE,
                            'public_key'    => get_option( 'wc_protect_public_key' )
                        ),
                        $updateUrl
                    ),
                    array(
                        'timeout' => 10,
                        'headers' => array(
                            'Accept' => 'application/json'
                        )
                    )
                );

                if(
                    is_wp_error( $remote )
                    || 200 !== wp_remote_retrieve_response_code( $remote )
                    || empty( wp_remote_retrieve_body( $remote ) )
                ) {
                    return false;
                }

                set_transient( $this->cache_key, $remote, DAY_IN_SECONDS );

            }

            $remote = json_decode( wp_remote_retrieve_body( $remote ) );

            return $remote;
        }


        function info( $res, $action, $args ) {
            // print_r( $action );
            // print_r( $args );

            // do nothing if you're not getting plugin information right now
            if( 'plugin_information' !== $action ) {
                return $res;
            }

            // do nothing if it is not our plugin
            if(  empty( $args->slug ) || $this->plugin_slug !== $args->slug ) {
                return $res;
            }

            // get updates
            $remote = $this->request();

            if( ! $remote ) {
                return $res;
            }

            // print_r($remote);

            $res = new stdClass();

            try {
                $res->name              = $remote->name;
                $res->slug              = $remote->slug;
                $res->version           = $remote->version;
                $res->tested            = $remote->tested;
                $res->requires          = $remote->requires;
                $res->author            = $remote->author;
                $res->author_profile    = $remote->author_profile;
                $res->download_link     = $remote->download_url;
                $res->trunk             = $remote->download_url;
                $res->requires_php      = $remote->requires_php;
                $res->last_updated      = $remote->last_updated;

                $res->sections = array(
                    'description'   => $remote->sections->description,
                    'installation'  => $remote->sections->installation,
                    'changelog'     => $remote->sections->changelog
                );

                if( ! empty( $remote->banners ) ) {
                    $res->banners = array(
                        'low'       => $remote->banners->low,
                        'high'      => $remote->banners->high
                    );
                }
            } catch (Error $e) {

            }

            return $res;
        }

        public function update( $transient ) {

            if ( empty($transient->checked ) ) {
                return $transient;
            }

            $remote = $this->request();

            if(
                $remote
                && version_compare( $this->version, $remote->version, '<' )
                && version_compare( $remote->requires, get_bloginfo( 'version' ), '<=' )
                && version_compare( $remote->requires_php, PHP_VERSION, '<' )
            ) {
                $res                = new stdClass();
                $res->slug          = $this->plugin_slug;
                $res->plugin        = plugin_basename( __FILE__ );
                $res->new_version   = $remote->version;
                $res->tested        = $remote->tested;
                $res->package       = $remote->download_url;

                $transient->response[ $res->plugin ] = $res;
        }
            return $transient;
        }

        public function purge( $upgrader, $options ){

            if (
                $this->cache_allowed
                && 'update' === $options['action']
                && 'plugin' === $options[ 'type' ]
            ) {
                // just clean the cache when new plugin version is installed
                delete_transient( $this->cache_key );
            }

        }

    }

    new Woo_Protect_Updater();
}
?>
